**To delete an AWS CodeBuild build project**

The following ``delete-project`` example deletes the specified CodeBuild build project. ::

    aws codebuild delete-project --name my-project
    
This command produces no output.

For more information, see `Delete a Build Project (AWS CLI) <https://docs.aws.amazon.com/codebuild/latest/userguide/delete-project.html>`_ in the *AWS CodeBuild User Guide*.
